@@ -61,6 +61,7 @@ type Database interface {
 
 	GetMessageLastID(ctx context.Context, networkID int64, name string) (int64, error)
 	GetMessageTarget(ctx context.Context, networkID int64, target string) (*MessageTarget, error)
+	ListMessageTargets(ctx context.Context, networkID int64) ([]MessageTarget, error)
 	StoreMessageTarget(ctx context.Context, networkID int64, mt *MessageTarget) error
 	StoreMessages(ctx context.Context, networkID int64, name string, msgs []*irc.Message) ([]int64, error)
 	ListMessageLastPerTarget(ctx context.Context, networkID int64, options *MessageOptions) ([]MessageTargetLast, error)
@@ -290,10 +291,11 @@ type WebPushSubscription struct {
 }
 
 type MessageTarget struct {
-	ID     int64
-	Target string
-	Pinned bool
-	Muted  bool
+	ID      int64
+	Target  string
+	Pinned  bool
+	Muted   bool
+	Blocked bool
 }
 
 func toNullString(s string) sql.NullString {
