@@ -3,7 +3,7 @@
 package database
 
 import (
-	_ "git.sr.ht/~emersion/go-sqlite3-fts5"
+	_ "codeberg.org/emersion/go-sqlite3-fts5"
 	_ "github.com/mattn/go-sqlite3"
 )
 
